@@ -44,9 +44,9 @@ def verify_table(fn: str):
                 fn=fn, md5sum_is=md5sum_is, md5sum_should=md5sum_should))
 
 
-def get_tables_pypi(sicor_table_path=None, sensor="s2", export_options_to=None):
+def get_tables_pypi(sicor_path=None, sicor_table_path=None, sensor="s2"):
 
-    settings = os.path.join(os.path.dirname(options.__file__), "{sensor}_options.json".format(sensor=sensor))
+    settings = os.path.join(sicor_path, "options", "{sensor}_options.json".format(sensor=sensor))
     opts = get_options(settings)
     sicor_tables = ([opts['cld_mask']["persistence_file"], opts['cld_mask']["novelty_detector"]])
     sicor_tables_fn = {os.path.basename(fn) for fn in sicor_tables}
@@ -96,12 +96,7 @@ def get_tables_pypi(sicor_table_path=None, sensor="s2", export_options_to=None):
 
     new_opts = update_opts(opts)
 
-    if export_options_to is None:
-        opts_fn = os.path.join(os.path.dirname(options.__file__), "sicor_{sensor}_user_options.json".format(
-            sensor=sensor))
-    else:
-        os.makedirs(os.path.dirname(export_options_to), exist_ok=True)
-        opts_fn = export_options_to
+    opts_fn = os.path.join(sicor_path, "options", "sicor_{sensor}_user_options.json".format(sensor=sensor))
 
     print("Export user options to: %s" % opts_fn)
     with open(opts_fn, "w") as fl:
